@@ -19,6 +19,7 @@ import precipy.jinja_filters as jinja_filters
 import precipy.output_filters as output_filters
 import shutil
 import tempfile
+from precipy.identifiers import metadata_filename
 
 def generate_range_key(range_env):
     if range_env:
@@ -36,9 +37,7 @@ class Batch(object):
         # set specific options
         if self.config.get('opts', False):
             self.config['reset'] = self.config['opts'].reset
-            print("set config reset to '%s'" % self.config['reset'])
             self.config['forcedelete'] = self.config['opts'].forcedelete
-            print("set config forcedelete to '%s'" % self.config['forcedelete'])
 
         self.setup_work_dirs()
         self.setup_template_environment()
@@ -259,10 +258,11 @@ class Batch(object):
             if af.download_from_storages(af.metadata_cache_filepath()):
                 af.load_metadata()
                 for sf in af.files.values():
-                    self.logger.debug("    downloading supplemental file %s" % sf.canonical_filename)
-                    filepath = af.supplemental_file_cache_filepath(sf.canonical_filename)
-                    if not af.download_from_storages(filepath):
-                        raise Exception("couldn't download storage for %s" % filepath)
+                    if sf.canonical_filename != metadata_filename:
+                        self.logger.debug("    downloading supplemental file %s" % sf.canonical_filename)
+                        filepath = af.supplemental_file_cache_filepath(sf.canonical_filename)
+                        if not af.download_from_storages(filepath):
+                            raise Exception("couldn't download storage for %s" % filepath)
 
         if not af.metadata_path_exists():
             self.logger.debug("cached metadata not found locally or remotely, running the function")
@@ -366,7 +366,8 @@ class Batch(object):
                     if mode == 'cache':
                         self.upload_to_storages_cache(gf)
                     elif mode == 'output':
-                        self.upload_to_storages_output(gf)
+                        if gf.canonical_filename != metadata_filename:
+                            self.upload_to_storages_output(gf)
                     else:
                         raise Exception("unexpected mode '%s'" % mode)
 
