@@ -2,7 +2,8 @@ class Storage(object):
     def init(self, batch):
         self.cache_bucket_name = batch.cache_bucket_name
         self.output_bucket_name = batch.output_bucket_name
-        self.forcedelete = batch.config.get('forcedelete')
+        self.is_opt_reset = batch.is_opt_reset()
+        self.is_opt_forcedelete = batch.is_opt_forcedelete()
         self.logger = batch.logger
 
     def __repr__(self):
@@ -85,7 +86,7 @@ class GoogleCloudStorage(Storage):
             bucket = self.storage_client.get_bucket(bucket_name)
         except google.api_core.exceptions.NotFound:
             self.logger.debug("creating bucket %s" % bucket_name)
-            bucket = self.storage_client.create_public_bucket(bucket_name)
+            bucket = self.create_public_bucket(bucket_name)
         return bucket
 
     def create_safety_file(self, bucket):
@@ -111,7 +112,7 @@ class GoogleCloudStorage(Storage):
 
     def delete_cache_bucket(self):
         try:
-            if not self.forcedelete:
+            if not self.is_opt_forcedelete:
                 self.assert_safe_to_delete(self.cache_storage_bucket)
             self.cache_storage_bucket.delete(force=True)
         except ValueError:
@@ -122,7 +123,7 @@ class GoogleCloudStorage(Storage):
 
     def delete_output_bucket(self):
         try:
-            if not self.forcedelete:
+            if not self.is_opt_forcedelete:
                 self.assert_safe_to_delete(self.output_storage_bucket)
             self.output_storage_bucket.delete(force=True)
         except ValueError:
@@ -147,6 +148,7 @@ class GoogleCloudStorage(Storage):
         blob = self.cache_storage_bucket.blob(cache_filename)
         self.logger.debug("  uploading blob to cache for %s" % cache_filename)
         blob.upload_from_filename(str(cache_filepath))
+        self.logger.debug("      public url is %s" % blob.public_url)
         return blob.public_url
 
     def _download_cache(self, cache_filename, local_cache_filepath):
